// Pingus - A free Lemmings clone
// Copyright (C) 1999 Ingo Ruhnke <grumbel@gmx.de>

// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.

// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

#include <ClanLib/clanlayer2.h>

#include "SoundSpecs.hh"
#include "globals.hh"
#include "plf_datatypes.hh"
#include "Pingu.hh"
#include "ButtonPanel.hh"
#include "actions/pingu_actions.hh"

CL_Surface* ButtonPanel::button_cap;

ButtonPanel::ButtonPanel(PLF* plf)
{
  need_redraw = true;
  pressed_button = 2;

  vector<button_data> buttons = plf->get_buttons();

  for(unsigned int i=0; i < buttons.size(); ++i) {
    button.push_back(new ActionButton(38 * i,
				      CL_Display::get_height() - 56, buttons[i].name,
				      buttons[i].make_action));
  }
}

ButtonPanel::~ButtonPanel()
{
}

void
ButtonPanel::let_move() 
{
  for(unsigned int i=0; i < button.size(); ++i) {
    button[i]->let_move();
  }

  if (CL_Mouse::get_y() > CL_Display::get_height() - 56 && CL_Mouse::left_pressed()) {
    for(int i=0; static_cast<unsigned int>(i) < button.size(); ++i) {
      if (CL_Mouse::get_x() >= i * 38 && CL_Mouse::get_x() < ((i + 1)
							      * 38)) {
	if (sound_enabled) SoundSpecs::play(SoundSpecs::OING);
  
	pressed_button = i;
 	cap->set_action(get_action()); 
	break;
      }
    }
  }
}

PinguAction*
ButtonPanel::get_action()
{
  return button[pressed_button]->get_action();
}

string
ButtonPanel::get_action_name()
{
  return button[pressed_button]->get_action_name();
}

void 
ButtonPanel::draw() 
{
  need_redraw = true;
  if (need_redraw) {
    // draw the buttons
    for(unsigned int i=0; i < button.size(); ++i) {
      button[i]->draw();
    }
    need_redraw = false;
  }

  // draw the capture rectangle for the active button
  button_cap->put_screen(pressed_button*38, CL_Display::get_height() - 56);
}

void
ButtonPanel::load_data()
{
  button_cap      = CL_Res_Surface::load("Buttons/button_cap", *resource());
}

void
ButtonPanel::set_cap(CaptureRectangle* caprec)
{
  cap = caprec; 
}


/* EOF */
