// Pingus - A free Lemmings clone
// Copyright (C) 1999 Ingo Ruhnke <grumbel@gmx.de>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

#include "globals.hh"
#include "Client.hh"
#include "LevelMap.hh"
#include "ButtonPanel.hh"
#include "Window.hh"
#include "Playfield.hh"
#include "LevelInterrupt.hh"
#include "TimeDisplay.hh"
#include "PinguInfo.hh"

Client::Client(AbstractServer* s)
{
  server = s;
}

Result
Client::start(string filename)
{
  if (verbose) {
    cout << "Constructing Window Objs: " << filename << endl;
  }

  //  Result result;
  PLF*         plf          = new PLF(filename);
  Window*      game         = new Window();

  // Create GuiObj for Window* game 
  Playfield*   playfield    = new Playfield(plf, server->get_world());
  ButtonPanel* button_panel = new ButtonPanel(plf);
  LevelMap*    level_map    = new LevelMap(plf);
  TimeDisplay* time_display = new TimeDisplay();
  PinguInfo*   pingu_info   = new PinguInfo();
  
  if (verbose)
    cout << "Constructing Window Objs finished" << endl;

  if (music_enabled) {
    // Constructing Pingus Music
    music = new PingusMusic(plf);
    //  music->play();
  }

  playfield->set_clip_rect(0, 0, 
			   CL_Display::get_width(),
			   CL_Display::get_height() - 60);

  // Connect the button_panel with the playfield
  playfield->set_buttons(button_panel);
  playfield->set_pingu_info(pingu_info);

  // Add all objects to the window
  game->add_obj(playfield);
  game->add_obj(button_panel);
  game->add_obj(level_map);
  game->add_obj(time_display);
  game->add_obj(pingu_info);

  // Give main controll to the window
  if (verbose)
    cout << "Entering main_loop. Startup time: " 
	 << CL_System::get_time() << " msec." << endl;

  // This loop will never exit, only throu a throw/catch pair
  try {
    game->main_loop();
  }

  catch (LevelInterrupt i) {
    switch (i.status) {
    case LevelInterrupt::restart:
      start(filename);
      break;
    case LevelInterrupt::quit:
      cout << "Going to quit" << endl;
      break;
    default:
      cout << "Undefined value for LevelInterrupt" << endl;
      break;
    }
  }

  // Delete all alocated objects
  delete    level_map;
  delete button_panel;
  delete    playfield;
  delete         game;
  delete          plf;
}

/* EOF */










