// Pingus - A free Lemmings clone
// Copyright (C) 1999 Ingo Ruhnke <grumbel@gmx.de>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

#include <cassert>

#include "PinguAction.hh"

ColMap*   PinguAction::colmap;
PinguMap* PinguAction::map;

PinguAction::PinguAction()
{
  is_finished = false;
  font = CL_Res_Font::load("Fonts/numbers",*resource());  
}

PinguAction::~PinguAction()
{
}

void 
PinguAction::set_colmap(ColMap* cm)
{
  colmap = cm;
  assert(colmap);
}

void
PinguAction::set_map(PinguMap* m)
{
  map = m;
}

void
PinguAction::load_data()
{
}

// BUG: This function shouldn't be needed, it could implemented more cleanly
void
PinguAction::set_pingu_data(PinguData& pingu_data)
{
  data = &pingu_data;
  assert(data);
}

// Checks if the pingu action needs to catch another pingu (needed for 
// example by the blocker)
bool 
PinguAction::need_catch() { 
  return false; 
}

// Wrapper around the colmap, to get the pixels infront of the pingu,
// from is current position
int
PinguAction::rel_getpixel(int x, int y)
{
  assert(colmap);
  return colmap->getpixel(data->x_pos + (x * data->direction), (data->y_pos) - y);
}

bool
PinguAction::can_reset()
{
  return true;
}

void
PinguAction::draw_offset(int x, int y, double s=1.0)
{
  if (data->status == (dead || exited))
    return;

  assert(surface);
  
  if (is_multi_direct)
    surface->put_screen(int((data->x_pos + x -16) * s), int((data->y_pos + y -32) * s), 
                        int(surface->get_width() * s), int(surface->get_height() * s),
			++counter + ((data->direction.is_left()) ? 0 : counter.size()));
  else 
    surface->put_screen(int((data->x_pos + x -16) * s), int((data->y_pos + y -32) * s),
                        int(surface->get_width() * s), int(surface->get_height() * s),
                        ++counter);
}

PinguEnvironment
PinguAction::get_environment()
{
 return environment;
}

/* EOF */
