// Pingus - A free Lemmings clone
// Copyright (C) 1999 Ingo Ruhnke <grumbel@gmx.de>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

#ifndef PINGU_ACTION_HH
#define PINGU_ACTION_HH

#include <ClanLib/clanlib.h>
#include <ClanLib/clanlayer2.h>

#include "AnimCounter.hh"
#include "PinguData.hh"
#include "ColMap.hh"
#include "PinguMap.hh"
#include "GameObj.hh"

class Pingu; // BUG: IMHO Bad style, declare Pingus in an file different than pingu.hh

// This class provides an abstract interface for pingu actions. It is 
// used to inherit classes which are used to let the pingu walk.
class PinguAction : public GameObj
{
protected:
  CL_Surface* surface;  // The basic surface, the inherited class can
                        // define other surfaces if it needs more.
  CL_Font*    font;     // The font used for counting (used by the bomber)
  AnimCounter counter;  // Sets the speed and number of frames
  bool is_multi_direct; // This variable is needed in the draw_offset function
  PinguData* data;
  PinguEnvironment environment; //Environment mask to see if action is applicable

  // Static Variables
  static ColMap* colmap;
  static PinguMap*  map;
public:
  PinguAction();
  virtual ~PinguAction();

  virtual void let_move() = 0;     // The "AI" of the pingu, there is no default AI
  virtual void draw_offset(int x, int y, double s=1.0); //
  void set_pingu_data(PinguData&);
  int  rel_getpixel(int x, int y);
  virtual bool can_reset();

  virtual char* name() = 0;
  virtual bool need_catch();
  virtual void catch_pingu(PinguData*) {};
  virtual int  activation_time() { return -1; }; // The time the
  // action needs to get activated
  
  bool is_finished;     // Indicate if the action should be canceled
                        // at the next possible point

  static void set_colmap(ColMap*);
  static void set_map(PinguMap*);
  static void load_data();
  PinguEnvironment get_environment(); 
};

#endif

/* EOF */
