// Pingus - A free Lemmings clone
// Copyright (C) 1999 Ingo Ruhnke <grumbel@gmx.de>

// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.

// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

#ifndef WORLD_HH
#define WORLD_HH

#include <ClanLib/clanlib.h>
#include <vector>

#include "GameObj.hh"
#include "PLF.hh"
#include "Pingu.hh"
#include "Background.hh"
#include "ColMap.hh"
#include "Entrance.hh"
#include "Exit.hh"
#include "Hotspot.hh"
#include "Trap.hh"
#include "traps/traps.hh"
#include "Result.hh"
#include "ParticleHolder.hh"

// World holds all object of the pingu world (pingus, traps, exits,
// entrances, etc.). It keeps control that all objects become time to
// move and can catch each other. 
class World : public GameObj
{
private:
  PinguMap*  map;
  Background* bg;
  unsigned int released_pingus;
  unsigned int allowed_pingus;
  Result* result;

  vector<Entrance*> entrance;
  vector<Exit*>     exits;

  vector<Hotspot*>  hotspot_fg;
  vector<Hotspot*>  hotspot_bg;

  vector<Trap*>   traps;
  ParticleHolder particle;
  CL_InputSourceProvider* datafile;

  void draw_background(int x_offset, int y_offset, double s = 1.0) const;
  void draw_pingus(int x_offset, int y_offset, double s = 1.0) const;
  void draw_playground(int x_offset, int y_offset, double s = 1.0) const;
  void draw_foreground(int x_offset, int y_offset, double s = 1.0) const;

public:
  World();
  virtual ~World();

  void draw_offset(int x, int y, double s=1.0) const;

  void save();
  void load();
  void load_data(CL_InputSourceProvider*);
  void init(PLF*, Result&);
  void let_move();
  void armageddon(void);
  int  get_height();
  int  get_width();
  void write_results();
  vector<Pingu*>* get_pingu_p();

  ColMap* colmap;
  static void load_data();
  vector<Pingu*> pingu;
};

#endif

/* EOF */
